@@ -1,7 +1,7 @@
 package Text::ANSI::BaseUtil;
 
-our $DATE = '2015-08-20'; # DATE
-our $VERSION = '0.21'; # VERSION
+our $DATE = '2016-03-11'; # DATE
+our $VERSION = '0.22'; # VERSION
 
 use 5.010001;
 use strict;
@@ -514,7 +514,7 @@ sub _ta_pad {
             my $n = int(($width-$w)/2);
             $text = ($padchar x $n) . $text . ($padchar x ($width-$w-$n));
         } else {
-            $text .= ($padchar x ($width-$w));
+            $text .= ($padchar x ($width-$w)) if $width > $w;
         }
     }
     $text;
@@ -820,7 +820,7 @@ sub ta_mbsubstr {
 
 
 1;
-# ABSTRACT: Base for Text::ANSI::{Util,NonWideUtil,WideUtil}
+# ABSTRACT: Base for Text::ANSI::{Util,WideUtil}
 
 __END__
 
@@ -830,13 +830,13 @@ __END__
 
 =head1 NAME
 
-Text::ANSI::BaseUtil - Base for Text::ANSI::{Util,NonWideUtil,WideUtil}
+Text::ANSI::BaseUtil - Base for Text::ANSI::{Util,WideUtil}
 
 =head1 VERSION
 
-This document describes version 0.21 of Text::ANSI::BaseUtil (from Perl distribution Text-ANSI-Util), released on 2015-08-20.
+This document describes version 0.22 of Text::ANSI::BaseUtil (from Perl distribution Text-ANSI-Util), released on 2016-03-11.
 
-=for Pod::Coverage .+
+=for Pod::Coverage .*
 
 =head1 HOMEPAGE
 
@@ -860,7 +860,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
